@@ -21,8 +21,11 @@ gltc.iso <- function(x, glottolog.source = "modified") {
   )
   x <- gsub("\\W", "", x)
   vapply(x, function(y) {
+    if(is.na(y)){
+      NA_character_
+    } else{
     ifelse(y %in% glottolog$iso,
            glottolog[tolower(glottolog$iso) %in% tolower(y), ]$glottocode,
            NA_character_)
-  }, character(1))
+  }}, character(1))
 }
